package webSocket;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.ejb.Singleton;
import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import javax.websocket.RemoteEndpoint;
import javax.websocket.Session;
import javax.websocket.server.ServerEndpoint;

@ServerEndpoint("/muro")
@Singleton
public class ControladorMuro {

    static final Logger LOGGER = Logger.getLogger(ControladorMuro.class.getName());
    
    //Lista de conexiones
    static final List<Session> conexiones = new ArrayList<>();

    //Cuando un cliente se conecta
    @OnOpen
    public void iniciaSesion(Session session) {
        System.out.println("Iniciando conexión");
        conexiones.add(session); //Lo agregamos a la lista de conexiones
    }

    //Se elimina de la lista de conexiones
    @OnClose
    public void finConexion(Session session) throws IOException {
        System.out.println("Terminando conexion");
        //¿Estaba incluido en la conexión?
        if (conexiones.contains(session)) {
            session.close();
            conexiones.remove(session);
        }
    }

    //se envía mensaje a todos los conectados
    public void notificar(String mensaje) {
        for (Session sesion : conexiones) { //Para cada conexión
            RemoteEndpoint.Basic remote = sesion.getBasicRemote(); //punto de la conexión para enviar mensajes
            try {
                remote.sendText(mensaje); //envío en mensaje
            } catch (IOException ex) {
                LOGGER.log(Level.WARNING, null, ex);
            }
        }

    }

    //Se recibe un mensaje y se notifica a todos los usuarios
    @OnMessage
    public void onMessage(String mensaje, Session sesion) {
        notificar(mensaje);
    }

}
